@@ -14,3 +14,7 @@ class ParticleFilter(g4.GateParticleFilter, gate.UserElement):
         g4.GateParticleFilter.__init__(self)  # no argument in cpp side
         gate.UserElement.__init__(self, user_info)
         # type_name MUST be defined in class that inherit from a Filter
+
+    def __getstate__(self):
+        # needed to not pickle the g4.GateParticleFilter
+        return self.__dict__
