@@ -2,10 +2,9 @@
 # -*- coding: utf-8 -*-
 
 import opengate as gate
-from test013_phys_lists_base import create_pl_sim, phys_em_parameters
-import pathlib
+from test013_phys_lists_helpers import create_pl_sim, phys_em_parameters
 
-pathFile = pathlib.Path(__file__).parent.resolve()
+paths = gate.get_default_test_paths(__file__, "gate_test013_phys_lists")
 
 # create simulation
 sim = create_pl_sim()
@@ -28,9 +27,6 @@ cuts.world.electron = 7 * um
 cuts.world.positron = 7 * um
 cuts.world.proton = 7 * um
 
-# initialize
-sim.initialize()
-
 # em parameters
 # phys_em_parameters(p)
 
@@ -40,19 +36,11 @@ print(sim.physics_manager.dump_cuts())
 
 # start simulation
 # sim.apply_g4_command("/tracking/verbose 1")
-sim.start()
+output = sim.start()
 
 # Gate mac/main_1.mac
-stats = sim.get_actor("Stats")
-stats_ref = gate.read_stat_file(
-    pathFile
-    / ".."
-    / "data"
-    / "gate"
-    / "gate_test013_phys_lists"
-    / "output"
-    / "stat_1.txt"
-)
-is_ok = gate.assert_stats(stats, stats_ref, tolerance=0.2)
+stats = output.get_actor("Stats")
+stats_ref = gate.read_stat_file(paths.gate_output / "stat_1.txt")
+is_ok = gate.assert_stats(stats, stats_ref, tolerance=0.1)
 
 gate.test_ok(is_ok)
