@@ -2,16 +2,15 @@
 # -*- coding: utf-8 -*-
 
 import opengate as gate
-from test013_phys_lists_base import create_pl_sim, phys_em_parameters
-import pathlib
+from test013_phys_lists_helpers import create_pl_sim, phys_em_parameters
 
-pathFile = pathlib.Path(__file__).parent.resolve()
+paths = gate.get_default_test_paths(__file__, "gate_test013_phys_lists")
 
 # create simulation
 sim = create_pl_sim()
 
 # keep only ion sources
-# sim.source_manager.user_info_sources.pop("gamma")
+sim.source_manager.user_info_sources.pop("gamma")
 
 # change physics
 p = sim.get_physics_user_info()
@@ -29,9 +28,6 @@ cuts.b1.electron = 0.01 * mm
 cuts.b1.positron = 1 * mm
 cuts.b1.proton = 1 * mm
 
-# initialize
-sim.initialize()
-
 # em parameters
 phys_em_parameters(p)
 
@@ -41,19 +37,11 @@ print(sim.physics_manager.dump_cuts())
 # start simulation
 # sim.set_g4_verbose(True)
 # sim.apply_g4_command("/tracking/verbose 1")
-sim.start()
+output = sim.start()
 
 # Gate mac/main_3.mac
-stats = sim.get_actor("Stats")
-stats_ref = gate.read_stat_file(
-    pathFile
-    / ".."
-    / "data"
-    / "gate"
-    / "gate_test013_phys_lists"
-    / "output"
-    / "stat_3.txt"
-)
+stats = output.get_actor("Stats")
+stats_ref = gate.read_stat_file(paths.gate_output / "stat_3.txt")
 is_ok = gate.assert_stats(stats, stats_ref, tolerance=0.1)
 
 gate.test_ok(is_ok)
