@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-import test019_linac_phsp_base as t
+import test019_linac_phsp_helpers as t
 
 sim = t.init_test019(3)
 t.run_test019(sim)
